# Copyright 2015 Andy Tzeng <andytzeng@aol.tw>. All Rights Reserved.
# Licensed under BSD 3-Clause License.
import regex

from . import express


class Base(object):

    pattern = None

    def __init__(self):
        if not self.pattern:
            raise ValueError('invalid pattern')

        self.re_url = regex.compile(self.pattern, regex.POSIX)

    def findfirst(self, string):
        match = self.re_url.search(string)
        if match:
            return match.group()

    def findall(self, string):
        return [x.group() for x in self.re_url.finditer(string)]


class Strict(Base):
    pattern = express.strict_exp()


class Relaxed(Base):
    pattern = express.relaxed_exp()


class StrictScheme(Base):

    def __init__(self, scheme_exp):
        self.pattern = express.strict_matching_scheme(scheme_exp)
        super().__init__()



# Copyright 2015 Andy Tzeng <andytzeng@aol.tw>. All Rights Reserved.
# Licensed under BSD 3-Clause License.

# Refer the tool unicodegen from mvdan.cc/xurls/v2

# PseudoTLDs is a sorted list of some widely used unofficial TLDs.
#
# Sources:
#  * https://en.wikipedia.org/wiki/Pseudo-top-level_domain
#  * https://en.wikipedia.org/wiki/Category:Pseudo-top-level_domains
#  * https://tools.ietf.org/html/draft-grothoff-iesg-special-use-p2p-names-00
#  * https://www.iana.org/assignments/special-use-domain-names/special-use-domain-names.xhtml
PseudoTLDs = [
    'bit',  # Namecoin
    'example',  # Example domain
    'exit',  # Tor exit node
    'gnu',  # GNS by public key
    'i2p',  # I2P network
    'invalid',  # Invalid domain
    'local',  # Local network
    'localhost',  # Local network
    'test',  # Test domain
    'zkey',  # GNS domain name
]



import setuptools

from os import path

# read the contents of your README file
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setuptools.setup(
    name='pyxurls',
    version='0.1.1',
    author='Andy Tzeng',
    author_email='andytzeng@aol.tw',
    description='A regular expression based URL extractor which extracts URLs from text.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/andytzeng/pyxurls',
    packages=setuptools.find_namespace_packages(include=['xurls']),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Text Processing',
        'Topic :: Text Processing :: General',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    install_requires=[
        'regex',
    ],
    python_requires='>=3.6',
)
